{% from 'libs/utils.jinja2' import reformat without context %}
{% from 'libs/utils.jinja2' import mbool without context %}
{# DON'T TOUCH THE INDENTATION !!! #}
                    <queue name="{{ node.name }}"

                        {#- header parameters -#}
                        {%- if node.max_consumers is defined -%}
                            {{- ' ' -}}
                        max-consumers="{{ node.max_consumers }}"
                        {%- endif -%}
                        {% if node.exclusive is defined -%}
                            {{- ' ' -}}
                        exclusive="{{ mbool(node.exclusive) }}"
                        {%- endif -%}
                        {% if node.purge_on_no_consumers is defined -%}
                            {{- ' ' -}}
                        purge-on-no-consumers="{{ mbool(node.purge_on_no_consumers) }}"
                        {%- endif -%}


                    {#- end header -#}
                    {%- if node.type == 'queue' -%}
                            />
                    {% elif node.type == 'queue_block' -%}
                            >
                    {% if node.durable is defined %}
                        <durable>{{ mbool(node.durable) }}</durable>
                    {%- endif %}
                    {% if node.filter is defined %}
                        <filter string="{{ node.filter }}"/>
                    {%- endif %}

                    </queue>
                    {% endif %}
