artemis_roles:
  amq:
  - admin
  - tckuser
  - superuser
  - administrator
  - charlie@MSGQE.COM
  senders:
  - alice@MSGQE.COM
  receivers:
  - bob@MSGQE.COM

artemis_users:
  admin: admin
  tckuser: tckuser
  superuser: superuser
  administrator: administrator
  nobody: nobody
