login_config:
  - name: activemq
    modules:
    - class_name: org.apache.activemq.artemis.spi.core.security.jaas.PropertiesLoginModule
      flag: sufficient
      properties:
      - debug: true
      - org.apache.activemq.jaas.properties.user: "artemis-users.properties"
      - org.apache.activemq.jaas.properties.role: "artemis-roles.properties"
