{% if broker_xml.acceptors is defined %}
    <!-- Acceptors configuration -->
        <acceptors>
    {% for acceptor in broker_xml.acceptors %}
            <acceptor name="{{ acceptor.name }}">
            {{- url(acceptor.protocol, acceptor.address, acceptor.port) -}}
            {%- if acceptor.properties is defined -%}
                ?
                {%- for option in acceptor.properties -%}
                    {%- for key, value in option.items() -%}{{ key }}={{ mbool(value) }}
                        {%- if not loop.last -%};
                        {%- endif -%}
                    {%- endfor -%}
                    {%- if not loop.last -%};
                    {%- endif -%}
                {%- endfor -%}
            {%- endif -%}

            </acceptor>
    {% endfor %}
        </acceptors>

{% endif %}
