{% if profile == 'default' %}
  {% include 'artemis/2.15.0/_modules/artemis_profile/default.yaml.jinja2' %}
{% elif profile == 'baseline' %}
  {% include 'artemis/2.15.0/_modules/artemis_profile/performance_baseline.yaml.jinja2' %}
{% elif profile == 'params' %}
  {% include 'artemis/2.15.0/_modules/artemis_profile/performance_params.yaml.jinja2' %}
{% endif %}
