  address_settings:
  - match: '#'
    dead_letter_address: DLQ
    expiry_address: ExpiryQueue
    redelivery_delay: 0
    max_size_bytes: -1
    message_counter_history_day_limit: 10
    address_full_policy: PAGE
    auto_create_queues: false
    auto_create_addresses: false
    auto_create_jms_queues: false
    auto_create_jms_topics: false
